==> haskell-either-5.0.3-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-Ofj8z9dcLGLwajoO9mRz5
key:                  either-5.0.3-Ofj8z9dcLGLwajoO9mRz5
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  ca3f9137244c2f344c481dd4b10af0e3
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-Ofj8z9dcLGLwajoO9mRz5
depends:
    base-4.17.2.1 bifunctors-5.6.2-GEXn7wFr46IB2mzTOaL0O6 mtl-2.2.2
    profunctors-5.6.3-5ykNj0b49W3C5puCJKHDiE
    semigroupoids-6.0.1-Aj0i7ZgNxib61OGk1aNVLj

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-either-5.0.3-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-either.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-DVRV7MwX651AHF1w4Fai0a
key:                  either-5.0.3-DVRV7MwX651AHF1w4Fai0a
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  04496ae855ec0fe3b62283614225d9f4
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-DVRV7MwX651AHF1w4Fai0a
depends:
    base-4.17.2.1 bifunctors-5.6.2-8qEFHnQSYft7mo1QPa8LDR mtl-2.2.2
    profunctors-5.6.3-KOZLO1xtOlQD6lxDMCq9YO
    semigroupoids-6.0.1-3CUWeXYcv8xJ5tqbj8MWiW

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
